% This routine fits a hyperbolic tangent to the germination rate data from
% the light and dark conditions.  The function tanhfit.m is used in
% conjunction with fminsearch to get the best fit in a least-squares sense.
%
% Charlie Stock
% cstock@alum.mit.edu
%

clear all
figure(1)
clf
figure(2)
clf

% Load in rate estimates (derived using gfit.m on raw germination time
% series)
load ../data/egom_light_rates;
load ../data/egom_dark_rates;
load ../data/wgom_light_rates;
load ../data/wgom_dark_rates;

egoml = egom_light_rates;
wgoml = wgom_light_rates;
egomd = egom_dark_rates;
wgomd = wgom_dark_rates;

% the temperature
xdark = [egomd(:,1)' wgomd(:,1)'];
xlight = [egoml(:,1)' wgoml(:,1)'];
% the estimated rates
ydark = [egomd(:,2)' wgomd(:,2)'];
ylight = [egoml(:,2)' wgoml(:,2)'];
% the 90% confidence intervals
edark = [egomd(:,3)' wgomd(:,3)'];
elight = [egoml(:,3)' wgoml(:,3)'];

dat_temp(:,1) = xlight';
dat_temp(:,2) = ylight';

% tanhfit (high,low,alpha,beta):
% rate = low + (high-low)*(0.5*(tanh(alpha*T - beta) + 1))
% estimate the light fit
options = optimset('tolfun',1e-5);
x0 = [8.0 1.0 0.5  8];
[xl,fval,exitflag,output] = fminsearch('tanhfit',x0,options,dat_temp);

% plot it up light estimates
figure(1)
title('Germination as a Function of Temperature (Light)')
hold on
plot(egoml(:,1),egoml(:,2),'ko');
a = plot(wgoml(:,1),wgoml(:,2),'ko');
set(a,'MarkerFaceColor',[0 0 0]);
legend('EGOM','WGOM',2);
% plot the light w/error bar 
dat = egoml;
errorbar(dat(:,1),dat(:,2),dat(:,3),'ko')
clear dat;
dat = wgoml;
b = errorbar(dat(:,1), dat(:,2),dat(:,3),'ko');
set(b,'MarkerFaceColor',[0 0 0]);
xfit = [0:0.1:20];
yfit = xl(2) + (xl(1) - xl(2))*0.5*(tanh(xl(3)*xfit - xl(4)) + 1);
plot(xfit,yfit,'k-','LineWidth',2);
xlabel('temperature (deg. C)');
ylabel('% germination/day');
set(gca,'FontSize',10,'FontName','Times-Roman');

dat_temp(:,1) = xdark';
dat_temp(:,2) = ydark';

options = optimset('tolfun',1e-5);
x0 = [5.0 1.0 0.5  8];
[xd,fval,exitflag,output] = fminsearch('tanhfit',x0,options,dat_temp);

figure(2)
title('Germination as a Function of Temperature (Dark)')
hold on
plot(egomd(:,1),egomd(:,2),'ko');
a = plot(wgomd(:,1),wgomd(:,2),'ko');
set(a,'MarkerFaceColor',[0 0 0]);
legend('EGOM','WGOM',2);
% plot the light w/error bar
dat = egomd;
errorbar(dat(:,1),dat(:,2),dat(:,3),'ko')
clear dat;
dat = wgomd;
b = errorbar(dat(:,1), dat(:,2),dat(:,3),'ko');
set(b,'MarkerFaceColor',[0 0 0]);
xfit = [0:0.1:20];
yfit = xd(2) + (xd(1) - xd(2))*0.5*(tanh(xd(3)*xfit - xd(4)) + 1);
plot(xfit,yfit,'k-','LineWidth',2);
xlabel('temperature (deg. C)');
ylabel('% germination/day');
set(gca,'FontSize',10,'FontName','Times-Roman');