% This routine was used define a reasonable range for the overall maximum
% growth rate (i.e. light saturated and at optimal T,S).  This parameter is
% not actually measured, but must be estimated using light saturated growth
% rates at given values of T and S.  If the data came from growth
% experiments that optimized over temperature, the maximum was calculated
% by taking the maximum growth at all temperatures and adjusting upward for 
% salinity only.  If the measurements were for a particular value of T and
% S, rates were adjusted upward for temperature and salinity.
%
% Charlie Stock
% cstock@alum.mit.edu

% Cullen et al. experiments at 32 ppt and 15 deg. C, maximum realized
% growth rates, rather than gross growth rates are used.
cullen = [0.4238 0.4296 0.4406 0.3737 0.3570 0.4531];
cullen_adj = cullen./(polyval(asn,32)*polyval(atn,15));

% Naragansett Bay Water (26.5-31.7 - use mid-point of 29.1), these points
% were maximized over temperature, so adjust for salinity only
langdon_adj = (log(2)*0.61)/polyval(asn,29.1);

% Watras optimized over both temperature and salinity
watras = 0.436;

% optimized over temperature, adjust for salinity only
keafer_adj = (log(2)*0.86)/polyval(asn,31);
kulis_adj = (log(2)*0.67)/polyval(asn,31);

% salinity = 30 for etheridge, these are from her light data at saturation
% but also at best temperature.
ethBOF_adj = 0.496/polyval(asn,30);
ethMI_adj = 0.682/polyval(asn,30);
 
data = [cullen_adj langdon_adj watras keafer_adj kulis_adj ethBOF_adj ethMI_adj];

mean(data)
std(data)
mean(data) + std(data)
mean(data) - std(data)
